#!/etc/opt/openit/perl

###############################################################################
#
# Clear sentinel filters introduced by add_sentinel_smt_filter.pl
#
#  - licpoll2 filters
#

BEGIN {
    push @INC, "/opt/openit/contrib/lib";
}

use strict;

use OpeniT::Contrib::Config;

my $config = new OpeniT::Contrib::Config;               # Reads default config file(s)
$config->read("/etc/opt/openit/openit_contrib.cfg");    # Additional config

#
# Get Open iT config directory (and verify value)
#
my $cfg_dir = $config->{CONFIG_DIR};
if (! -d $cfg_dir) {
    die "Unable to locate Open iT config ($cfg_dir) directory";
}

my $filter_var = "var5";

# Get list of filters to update

# get all licpoll2 
my @filter_files = &get_filters_to_update("$cfg_dir/filtrator");

foreach my $filter (@filter_files) {
    &update_filter( $filter );
}

exit 0;

###############################################################################
#
# Scan filter directory and get list of files to update
#
sub get_filters_to_update {
    my ($filter_dir) = @_;
    
    my @filters = glob("$filter_dir/*.conf");
    my @licpoll2_filters;
    
    foreach my $filter (@filters) {
    open(FILE, $filter) || die "Unable to read filter file '$filter'";
    my @lines = <FILE>;
    close(FILE);

    if( grep {/type\(String\)=\"licpoll2\"/} @lines ) {
        push( @licpoll2_filters, $filter );
    }
    }

    return @licpoll2_filters;
}

###############################################################################
#
# Update filter file with new filter
#
sub update_filter {
    my ($filter) = @_;
    print "Reading '$filter'\n";

    open(FILE, $filter) || die "Unable to read filter file '$filter'";
    my @lines = <FILE>;
    close(FILE);

    # Check that filter update is present
    my $update = grep {/Mapping:sentinel-products|Mapping:smt-to-all/} @lines;
    
    if ( !$update ) {
        print "Filter '$filter' need not be updated\n";
        return;
    }
    
    # Find filter contents to be removed
    my $ind = 0;
    
    $ind++ while( $lines[$ind] !~ /Mapping:sentinel-products/ );
    splice @lines, $ind, 2;
    $ind++ while( $lines[$ind] !~ /Mapping:smt-to-all/ );
    splice @lines, $ind, 2;
    
    $ind++ while( $lines[$ind] !~ /filter-defs/ );
    $ind-- while( $lines[$ind] !~ /\}/ );
    $ind--;
    
    $ind-- while( $lines[$ind] !~ /\}/ );
    splice @lines, $ind--, 1;
    $ind-- while( $lines[$ind] !~ /\}/ );
    splice @lines, $ind--, 1;
    
    $ind++ while( $lines[$ind] !~ /Mapping:sentinel-products/ );
    splice @lines, $ind, 8;
    $ind++ while( $lines[$ind] !~ /Mapping:smt-to-all/ );
    splice @lines, $ind, 9;
 
    $ind++ while( $lines[$ind] !~ /Duplicate:license-usage/ && $lines[$ind] !~ /Duplicate:version/ );
    $ind++ while( $lines[$ind] !~ /limiting\(String\)/ );
    
    if ( $lines[$ind] =~ /limiting\(String\)="\$.* != 'SENTINEL_PRODUCT'"\{\}/ ) {
        splice @lines, $ind, 1;
    }
    elsif ( $lines[$ind] =~ /.*limiting.*\( .* \).*/ ) {
        my $old_limiting = $lines[$ind];
        $old_limiting =~ /.*limiting.*\( (.*) \).*/;
        $lines[$ind] = "\t\t\tlimiting(String)=\"$1\"{}\n";
    }
    
    # Save the file 
    my $new = "$filter.new";
    my $old = "$filter.old";

    # Create new tmp file
    open(OUT, ">$new") || die "Unable to create tmp file '$new'";
    print OUT @lines;
    close(OUT);

    # Mv old file to .old
    if ( ! rename $filter, $old ) {
        die "Unable to rename '$filter'";
    }

    # Rename new
    if ( ! rename $new, $filter ) {
        die "Unable to rename '$new'";
    }

}